@@ -10,11 +10,11 @@ Test::WWW::Mechanize - Testing-specific WWW::Mechanize subclass
 
 =head1 VERSION
 
-Version 1.56
+Version 1.58
 
 =cut
 
-our $VERSION = '1.56';
+our $VERSION = '1.58';
 
 =head1 SYNOPSIS
 
@@ -233,10 +233,18 @@ sub _post_load_validation {
 
         if ( !$emitted_ok ) {
             $TB->ok( $ok, $desc );
+            if ( !$ok ) {
+                # Only show the URL and not the response message, because the
+                # problem is with the lint/tidy, not the fetching of the URL.
+                my $url = $self->_diag_url();
+                $TB->diag( $url ) if $url;
+            }
         }
     }
     else {
         $TB->ok( $ok, $desc );
+        my $url = $self->_diag_url();
+        $TB->diag( $url ) if $url;
         $TB->diag( $self->status );
         $TB->diag( $self->response->message ) if $self->response;
     }
@@ -244,6 +252,7 @@ sub _post_load_validation {
     return $ok;
 }
 
+
 =head2 $mech->head_ok($url, [ \%LWP_options ,] $desc)
 
 A wrapper around WWW::Mechanize's head(), with similar options, except
@@ -265,6 +274,8 @@ sub head_ok {
 
     $TB->ok( $ok, $desc );
     if ( !$ok ) {
+        my $url = $self->_diag_url();
+        $TB->diag( $url ) if $url;
         $TB->diag( $self->status );
         $TB->diag( $self->response->message ) if $self->response;
     }
@@ -323,6 +334,8 @@ sub put_ok {
     my $ok = $self->success;
     $TB->ok( $ok, $desc );
     if ( !$ok ) {
+        my $url = $self->_diag_url();
+        $TB->diag( $url ) if $url;
         $TB->diag( $self->status );
         $TB->diag( $self->response->message ) if $self->response;
     }
@@ -1641,7 +1654,7 @@ sub scraped_id_like {
 }
 
 
-=head2 id_exists( $id )
+=head2 $mech->id_exists( $id )
 
 Returns TRUE/FALSE if the given ID exists in the given HTML, or if none
 is provided, then the current page.
@@ -2251,6 +2264,16 @@ sub check_all_images_ok {
     return $ok;
 }
 
+
+sub _diag_url {
+    my $self = shift;
+
+    my $uri = $self->uri;
+
+    return $uri ? $uri->as_string : 'Unable to determine URL';
+}
+
+
 =head1 TODO
 
 Add HTML::Tidy capabilities.
